"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Debug = require("debug");
const debug = Debug("apifs:handler");
const Gateway_1 = require("./Gateway");
const pjson = require("../package.json");
class RequestHandler {
    constructor(gateway) {
        this.gateway = gateway;
        this.functions = this.gateway.functionsConfig.functions;
    }
    findFunctionForRequest(request) {
        // NOTE: this is slow and does not allow for custom (express like)
        // route matching.. however its fast enough for now
        for (const func of this.functions) {
            if (func.method === request.method &&
                func.gatewayPath === request.path) {
                return func;
            }
        }
        return null;
    }
    pipeHeaders(request) {
        const headers = request.headers;
        Gateway_1.BAD_PROXY_HEADERS.forEach((badProxyHeader) => {
            if (headers[badProxyHeader]) {
                delete headers[badProxyHeader];
            }
        });
        return headers;
    }
    async handleAuthentication(request, authType) {
        // TODO: handle different authentication types
        return true;
    }
    async handle(request, response) {
        debug("Handling request", request.url, request.method);
        const config = this.findFunctionForRequest(request);
        if (!config) {
            response.status(404).json({
                error: "No function is configured for this endpoint",
            });
            return;
        }
        if (!this.handleAuthentication(request, config.authType)) {
            response.status(403).json({
                error: "Provided authentication parameters are not satisfactory",
            });
            return;
        }
        const callOptions = {
            method: config.method,
            url: config.functionUrl,
            timeout: config.timeout || Gateway_1.DEFAULT_TIMEOUT,
            headers: this.pipeHeaders(request),
            body: request.body,
        };
        // make sure to overwrite
        callOptions.headers[Gateway_1.SECRET_HEADER] = config.secret;
        const { status, headers, body, } = await this.gateway.circuitClient.call(callOptions);
        response.status(status);
        response.set(headers);
        // overwrite
        response.set("x-powered-by", `${pjson.name}/${pjson.version}`);
        // NOTE: slow, this should be piped, but fine for now
        response.json(body);
    }
}
exports.default = RequestHandler;
